@@ -11,6 +11,9 @@ from gpt_index.data_structs.struct_type import IndexStructType
 from gpt_index.embeddings.langchain import LangchainEmbedding
 from gpt_index.embeddings.openai import OpenAIEmbedding
 
+# structured
+from gpt_index.indices.common.struct_store.base import SQLContextBuilder
+
 # indices
 from gpt_index.indices.keyword_table import (
     GPTKeywordTableIndex,
@@ -24,6 +27,7 @@ from gpt_index.indices.prompt_helper import PromptHelper
 
 # for composability
 from gpt_index.indices.query.schema import QueryConfig, QueryMode
+from gpt_index.indices.struct_store.sql import GPTSQLStructStoreIndex
 from gpt_index.indices.tree import GPTTreeIndex
 from gpt_index.indices.vector_store import (
     GPTFaissIndex,
@@ -33,6 +37,7 @@ from gpt_index.indices.vector_store import (
 
 # langchain helper
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
+from gpt_index.langchain_helpers.sql_wrapper import SQLDatabase
 
 # prompts
 from gpt_index.prompts.base import Prompt
@@ -57,14 +62,16 @@ from gpt_index.readers import (
     PineconeReader,
     SimpleDirectoryReader,
     SimpleMongoReader,
+    SimpleWebPageReader,
     SlackReader,
     StringIterableReader,
+    TrafilaturaWebReader,
     WeaviateReader,
     WikipediaReader,
 )
 
 # token predictor
-from gpt_index.token_predictor.mock_chain_wrapper import MockLLMPredictor
+from gpt_index.token_counter.mock_chain_wrapper import MockLLMPredictor
 
 __all__ = [
     "GPTKeywordTableIndex",
@@ -75,6 +82,7 @@ __all__ = [
     "GPTFaissIndex",
     "GPTSimpleVectorIndex",
     "GPTWeaviateIndex",
+    "GPTSQLStructStoreIndex",
     "Prompt",
     "LangchainEmbedding",
     "OpenAIEmbedding",
@@ -98,8 +106,12 @@ __all__ = [
     "FaissReader",
     "PineconeReader",
     "DiscordReader",
+    "SimpleWebPageReader",
+    "TrafilaturaWebReader",
     "LLMPredictor",
     "MockLLMPredictor",
+    "SQLDatabase",
+    "SQLContextBuilder",
     "PromptHelper",
     "QueryConfig",
     "QueryMode",
