@@ -16,15 +16,17 @@ from typing import (
 
 from gpt_index.data_structs.data_structs import IndexStruct, Node
 from gpt_index.data_structs.struct_type import IndexStructType
+from gpt_index.embeddings.base import BaseEmbedding
+from gpt_index.embeddings.openai import OpenAIEmbedding
 from gpt_index.indices.prompt_helper import PromptHelper
 from gpt_index.indices.query.query_runner import QueryRunner
 from gpt_index.indices.query.schema import QueryConfig, QueryMode
-from gpt_index.indices.response.schema import Response
 from gpt_index.indices.utils import truncate_text
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
 from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
+from gpt_index.response.schema import Response
 from gpt_index.schema import BaseDocument, DocumentStore
-from gpt_index.utils import llm_token_counter
+from gpt_index.token_counter.token_counter import llm_token_counter
 
 IS = TypeVar("IS", bound=IndexStruct)
 
@@ -46,6 +48,9 @@ class BaseGPTIndex(Generic[IS]):
             will use the default chunk size limit (4096 max input size).
         verbose (bool): Optional bool. If True, will print out additional information
             during the index building process.
+        include_extra_info (bool): Optional bool. If True, extra info (i.e. metadata)
+            of each Document will be prepended to its text to help with queries.
+            Default is True.
 
     """
 
@@ -56,10 +61,12 @@ class BaseGPTIndex(Generic[IS]):
         documents: Optional[Sequence[DOCUMENTS_INPUT]] = None,
         index_struct: Optional[IS] = None,
         llm_predictor: Optional[LLMPredictor] = None,
+        embed_model: Optional[BaseEmbedding] = None,
         docstore: Optional[DocumentStore] = None,
         prompt_helper: Optional[PromptHelper] = None,
         chunk_size_limit: Optional[int] = None,
         verbose: bool = False,
+        include_extra_info: bool = True,
     ) -> None:
         """Initialize with parameters."""
         if index_struct is None and documents is None:
@@ -68,6 +75,9 @@ class BaseGPTIndex(Generic[IS]):
             raise ValueError("Only one of documents or index_struct can be provided.")
 
         self._llm_predictor = llm_predictor or LLMPredictor()
+        # NOTE: the embed_model isn't used in all indices
+        self._embed_model = embed_model or OpenAIEmbedding()
+        self._include_extra_info = include_extra_info
 
         # TODO: move out of base if we need custom params per index
         self._prompt_helper = prompt_helper or PromptHelper.from_llm_predictor(
@@ -97,8 +107,15 @@ class BaseGPTIndex(Generic[IS]):
         """Get the llm predictor."""
         return self._llm_predictor
 
+    @property
+    def embed_model(self) -> BaseEmbedding:
+        """Get the llm predictor."""
+        return self._embed_model
+
     def _process_documents(
-        self, documents: Sequence[DOCUMENTS_INPUT], docstore: DocumentStore
+        self,
+        documents: Sequence[DOCUMENTS_INPUT],
+        docstore: DocumentStore,
     ) -> List[BaseDocument]:
         """Process documents."""
         results = []
@@ -188,6 +205,7 @@ class BaseGPTIndex(Generic[IS]):
                 index=start_idx + i,
                 ref_doc_id=document.get_doc_id(),
                 embedding=document.embedding,
+                extra_info=document.extra_info if self._include_extra_info else None,
             )
             nodes.append(node)
         return nodes
@@ -297,6 +315,7 @@ class BaseGPTIndex(Generic[IS]):
             query_runner = QueryRunner(
                 self._llm_predictor,
                 self._prompt_helper,
+                self._embed_model,
                 self._docstore,
                 query_configs=query_configs,
                 verbose=verbose,
@@ -314,6 +333,7 @@ class BaseGPTIndex(Generic[IS]):
             query_runner = QueryRunner(
                 self._llm_predictor,
                 self._prompt_helper,
+                self._embed_model,
                 self._docstore,
                 query_configs=[query_config],
                 verbose=verbose,
