@@ -3,7 +3,6 @@ from typing import Any, List, Optional, Tuple
 
 from gpt_index.data_structs.data_structs import IndexList, Node
 from gpt_index.embeddings.base import BaseEmbedding
-from gpt_index.embeddings.openai import OpenAIEmbedding
 from gpt_index.indices.query.embedding_utils import get_top_k_embeddings
 from gpt_index.indices.query.list.query import BaseGPTListIndexQuery
 
@@ -34,9 +33,9 @@ class GPTListIndexEmbeddingQuery(BaseGPTListIndexQuery):
         """Initialize params."""
         super().__init__(
             index_struct=index_struct,
+            embed_model=embed_model,
             **kwargs,
         )
-        self._embed_model = embed_model or OpenAIEmbedding()
         self.similarity_top_k = similarity_top_k
 
     def _get_nodes_for_response(
@@ -58,7 +57,7 @@ class GPTListIndexEmbeddingQuery(BaseGPTListIndexQuery):
         top_k_nodes = [nodes[i] for i in top_idxs]
         if verbose:
             top_k_node_text = "\n".join([n.get_text() for n in top_k_nodes])
-            print(f"Top {len(top_idxs)} nodes:\n{top_k_node_text}")
+            print(f"> Top {len(top_idxs)} nodes:\n{top_k_node_text}")
         return top_k_nodes
 
     def _get_embeddings(
