@@ -5,7 +5,6 @@ from typing import Any, Generic, Optional, TypeVar
 
 from gpt_index.data_structs.data_structs import BaseIndexDict
 from gpt_index.embeddings.base import BaseEmbedding
-from gpt_index.embeddings.openai import OpenAIEmbedding
 from gpt_index.indices.query.base import BaseGPTIndexQuery
 
 BID = TypeVar("BID", bound=BaseIndexDict)
@@ -22,6 +21,5 @@ class BaseGPTVectorStoreIndexQuery(BaseGPTIndexQuery[BID], Generic[BID]):
         **kwargs: Any,
     ) -> None:
         """Initialize params."""
-        super().__init__(index_struct=index_struct, **kwargs)
-        self._embed_model = embed_model or OpenAIEmbedding()
+        super().__init__(index_struct=index_struct, embed_model=embed_model, **kwargs)
         self.similarity_top_k = similarity_top_k
