@@ -8,7 +8,6 @@ from typing import Any, Optional, Sequence, cast
 
 from gpt_index.data_structs.data_structs import WeaviateIndexStruct
 from gpt_index.embeddings.base import BaseEmbedding
-from gpt_index.embeddings.openai import OpenAIEmbedding
 from gpt_index.indices.base import DOCUMENTS_INPUT, BaseGPTIndex
 from gpt_index.indices.query.schema import QueryMode
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
@@ -76,11 +75,11 @@ class GPTWeaviateIndex(BaseGPTIndex[WeaviateIndexStruct]):
         WeaviateNode.create_schema(self.client, self.class_prefix)
 
         self.text_qa_template = text_qa_template or DEFAULT_TEXT_QA_PROMPT
-        self._embed_model = embed_model or OpenAIEmbedding()
         super().__init__(
             documents=documents,
             index_struct=index_struct,
             llm_predictor=llm_predictor,
+            embed_model=embed_model,
             **kwargs,
         )
         # NOTE: when building the vector store index, text_qa_template is not partially
