@@ -23,5 +23,14 @@ class PromptType(str, Enum):
     # query keyword extract
     QUERY_KEYWORD_EXTRACT = "query_keyword_extract"
 
+    # schema extract
+    SCHEMA_EXTRACT = "schema_extract"
+
+    # text to sql
+    TEXT_TO_SQL = "text_to_sql"
+
+    # table context
+    TABLE_CONTEXT = "table_context"
+
     # custom (by default)
     CUSTOM = "custom"
