@@ -16,6 +16,7 @@ from gpt_index.readers.faiss import FaissReader
 # readers
 from gpt_index.readers.file import SimpleDirectoryReader
 from gpt_index.readers.google.gdocs import GoogleDocsReader
+from gpt_index.readers.make_com.wrapper import MakeWrapper
 from gpt_index.readers.mongo import SimpleMongoReader
 from gpt_index.readers.notion import NotionPageReader
 from gpt_index.readers.pinecone import PineconeReader
@@ -23,6 +24,7 @@ from gpt_index.readers.schema.base import Document
 from gpt_index.readers.slack import SlackReader
 from gpt_index.readers.string_iterable import StringIterableReader
 from gpt_index.readers.weaviate.reader import WeaviateReader
+from gpt_index.readers.web import SimpleWebPageReader, TrafilaturaWebReader
 from gpt_index.readers.wikipedia import WikipediaReader
 
 __all__ = [
@@ -38,4 +40,7 @@ __all__ = [
     "FaissReader",
     "Document",
     "StringIterableReader",
+    "SimpleWebPageReader",
+    "TrafilaturaWebReader",
+    "MakeWrapper",
 ]
