@@ -1,6 +1,5 @@
 """Base schema for readers."""
 from dataclasses import dataclass
-from typing import Dict, Optional
 
 from langchain.docstore.document import Document as LCDocument
 
@@ -15,8 +14,6 @@ class Document(BaseDocument):
 
     """
 
-    extra_info: Optional[Dict] = None
-
     def __post_init__(self) -> None:
         """Post init."""
         if self.text is None:
