@@ -5,7 +5,10 @@ from gpt_index.prompts.prompts import (
     QueryKeywordExtractPrompt,
     QuestionAnswerPrompt,
     RefinePrompt,
+    SchemaExtractPrompt,
     SummaryPrompt,
+    TableContextPrompt,
+    TextToSQLPrompt,
     TreeInsertPrompt,
     TreeSelectPrompt,
 )
@@ -37,3 +40,14 @@ MOCK_QUERY_KEYWORD_EXTRACT_PROMPT_TMPL = "{max_keywords}\n{question}\n"
 MOCK_QUERY_KEYWORD_EXTRACT_PROMPT = QueryKeywordExtractPrompt(
     MOCK_QUERY_KEYWORD_EXTRACT_PROMPT_TMPL
 )
+
+
+MOCK_SCHEMA_EXTRACT_PROMPT_TMPL = "{text}\n{schema}"
+MOCK_SCHEMA_EXTRACT_PROMPT = SchemaExtractPrompt(MOCK_SCHEMA_EXTRACT_PROMPT_TMPL)
+
+MOCK_TEXT_TO_SQL_PROMPT_TMPL = "{schema}\n{query_str}"
+MOCK_TEXT_TO_SQL_PROMPT = TextToSQLPrompt(MOCK_TEXT_TO_SQL_PROMPT_TMPL)
+
+
+MOCK_TABLE_CONTEXT_PROMPT_TMPL = "{schema}\n{context_str}\n{query_str}"
+MOCK_TABLE_CONTEXT_PROMPT = TableContextPrompt(MOCK_TABLE_CONTEXT_PROMPT_TMPL)
